@@ -14,46 +14,41 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #
-# Authors: Quinn Storm (quinn@beryl-project.org)
+# Authors: Quinn Storm (livinglatexkali@gmail.com)
 #          Patrick Niklaus (patrick.niklaus@student.kit.edu)
 #          Guillaume Seguin (guillaume@segu.in)
 #          Christopher Williams (christopherw@verizon.net)
 #          Sorokin Alexei (sor.alexei@meowr.ru)
 # Copyright (C) 2007 Quinn Storm
 
-from gi.repository import Gtk, Gdk
+import os
+from gi.repository import GLib, Gtk, Gdk
 
-# Current Screen
+# Settings Grid
 #
-try:
-    CurrentScreenNum = Gdk.Display.get_default().get_default_screen().get_number()
-except (AttributeError, TypeError):
-    CurrentScreenNum = Gdk.Screen.get_default().get_number()
-
-# Settings Table
-#
-TableDef = Gtk.AttachOptions.FILL | Gtk.AttachOptions.EXPAND
-TableX   = 4
-TableY   = 2
+GridRow    = 4
+GridColumn = 2
 
 # Action Constants
 #
-KeyModifier = ["Shift", "Control", "Mod1", "Mod2", "Mod3", "Mod4",
-               "Mod5", "Alt", "Meta", "Super", "Hyper", "ModeSwitch"]
-Edges       = ["Left", "Right", "Top", "Bottom",
-               "TopLeft", "TopRight", "BottomLeft", "BottomRight"]
+KeyModifier      = ["Shift", "Control", "Mod2", "Mod3", "Mod4", "Mod5",
+                    "Alt", "Meta", "Super", "Hyper", "ModeSwitch"]
+KeyModifierAlias = [("Mod1", "Alt"), ("Primary", "Control")]
+Edges            = ["Left", "Right", "Top", "Bottom",
+                    "TopLeft", "TopRight", "BottomLeft", "BottomRight"]
 
 # Label Styles
 #
-HeaderMarkup = "<span size='large' weight='800'>%s</span>"
+HeaderMarkup = "<span foreground='%s' size='large' weight='800'>%s</span>"
+HeaderMarkupDefault = "<span size='large' weight='800'>%s</span>"
 
 # Image Types
 #
 ImageNone     = 0
 ImagePlugin   = 1
 ImageCategory = 2
-ImageThemed   = 3
-ImageStock    = 4
+ImageInternal = 3
+ImageThemed   = 4
 
 # Filter Levels
 #
@@ -65,13 +60,15 @@ FilterAll = FilterName | FilterLongDesc | FilterValue | FilterCategory
 
 # Paths
 #
-DataDir = "/usr/local/share"
-IconDir = DataDir+"/ccsm/icons"
-PixmapDir = DataDir+"/ccsm/images"
+DataDir = os.path.join("/usr/local", "share")
+IconDirs = (os.path.join(DataDir, "compiz", "icons"),
+            os.path.join(GLib.get_user_data_dir(), "compiz", "icons"),
+            os.path.join(GLib.get_home_dir(), ".compiz", "icons"))
+PixmapDir = os.path.join(DataDir, "ccsm", "images")
 
 # Version
 #
-Version = "0.8.14"
+Version = "0.8.18"
 
 
 # Translation
